/*-------------------------*/
/* Variables Description   */
/*-------------------------*/

/* year		~ years 							1954  -2005 	*/
/* quarters	~ quarters 							1954.I-2005.I 	*/
/* gdp_defl	~ gdp deflator 							1954.I-2005.I 	*/
/* gnp_defl	~ gnp deflator 							1954.I-2005.I 	*/
/* gdp		~ gdp	 							1954.I-2005.I 	*/
/* gnp		~ gnp 								1954.I-2005.I 	*/
/* dep_kp	~ depreciation private capital 					1954.I-2005.I 	*/
/* dep_kg	~ depreciation govern. capital					1954.I-2005.I 	*/
/* dep_kpr	~ real dep private capital 					1954.I-2005.I 	*/
/* dep_kgr	~ real dep govern. capital 					1954.I-2005.I 	*/
/* sdisp	~ statistical discrepancy: NNP-NI				1954.I-2005.I 	*/	
/* uli		~ unambiguous labor income 					1954.I-2005.I 	*/	
/* prop_inc	~ propietors income  						1954.I-2005.I 	*/	
/* rent_inc	~ rental income 						1954.I-2005.I 	*/	
/* corp_prof	~ corporations income 						1954.I-2005.I 	*/	
/* net_int	~ net interest income 						1954.I-2005.I 	*/	
/* ik		~ private capital investment 					1954.I-2005.I 	*/	
/* id		~ durables investment 						1954.I-2005.I 	*/	
/* ig		~ government investment 					1954.I-2005.I 	*/
/* invent	~ real inventories 						1954.I-2004.IV 	*/	
/* invent_c	~ current inventories 						1954.I-2004.IV 	*/
/* taxes	~ taxes on production and imports				1954.I-2005.I 	*/
/* subsid	~ subsidies							1954.I-2005.I 	*/
/* bus_t	~ business transfer payments					1954.I-2005.I 	*/
/* Gov_Ent	~ government enterprises surplus				1954.I-2005.I 	*/
/* w		~ wages								1954.I-2005.I 	*/
/* wgov		~ non-government wages 						1954.I-2005.I 	*/
/* wo		~ government wages 						1954.I-2005.I 	*/
/* wsup		~ contributions							1954.I-2005.I 	*/
/* wpens	~ contributions to pensions 					1954.I-2005.I 	*/
/* wss		~ contributions to social security 				1954.I-2005.I 	*/
/* n_ces	~ employment establishment survey 				1954.I-2003.IV 	*/
/* n_cps	~ employment household survey 					1954.I-2004.IV 	*/
/* h		~ aggregate hours establishment survey				1954.I-2002.IV	*/	
/* kp		~ real fixed reproducible private capital			1954.I-2003.IV 	*/	
/* kg		~ real government capital stock 				1954.I-2003.IV 	*/	
/* kd		~ real consumer durables capital stock 				1954.I-2003.IV 	*/	
/* kp_c		~ current fixed reproducible private capital			1954.I-2003.IV 	*/	
/* kg_c		~ current government capital stock 				1954.I-2003.IV 	*/	
/* kd_c		~ current consumer durables capital stock 			1954.I-2003.IV 	*/
/* dep_kdr	~ real depreciation consumer durables capital stock 		1954.I-2003.IV 	*/
/* dep_kd	~ depreciation consumer durables capital stock 			1954.I-2003.IV 	*/
/* res_land	~ residential land capital stock				1970.I-2004.II 	*/	
/* kp_a		~ annual real fixed reproducible private capital		1954  -2003 	*/	
/* kg_a		~ annual real government capital stock 				1954  -2003 	*/	
/* kd_a		~ annual real consumer durables capital stock 			1954  -2003 	*/	
/* kp_c_a	~ annual current fixed reproducible private capital		1954  -2003 	*/	
/* kg_c_a	~ annual current government capital stock 			1954  -2003 	*/	
/* kd_c_a	~ annual current consumer durables capital stock 		1954  -2003 	*/
/* dep_kdr_a	~ annual real depreciation consumer durables capital stock 	1954  -2003 	*/
/* dep_kd_a	~ annual depreciation consumer durables capital stock 		1954  -2003 	*/	

drop t

/* To compute labor share: use nominal data, to compute TFP: use real   */


/************************************************************************/
/* Flows are at annual rates, you may want to de-annualize them. 	*/
/* If so, you just need to divide these flow variables by 4 		*/
/* Here all are flow vbles except capital stocks, depreciation of 	*/
/*	consumer durables and inventories				*/
/************************************************************************/


/*	replace gdp=gdp/4
	replace gnp=gnp/4
	replace dep_kp=dep_kp/4
	replace dep_kg=dep_kg/4
	replace dep_kpr=dep_kpr/4
	replace dep_kgr=dep_kgr/4
	replace sdisp=sdisp/4
	replace uli=uli/4
	replace prop_inc=prop_inc/4
	replace rent_inc=rent_inc/4
	replace corp_pro=corp_pro/4
	replace net_int=net_int/4
	replace ik=ik/4
	replace ig=ig/4
	replace id=id/4
	replace taxes=taxes/4
	replace subsid=subsid/4
	replace bus_t=bus_t/4
	replace gov_ent=gov_ent/4	*/


/* We use only data until 2002 because our min-max (hours) is 2002.IV */

	drop if year>2004



/*-------------------------*/
/* generate time variable  */
/*-------------------------*/

	gen t=_n

	tsset t


/*-------------------------*/
/* generate capital income */
/*-------------------------*/

	/* depreciation: GNP-NNP */

	/* unambiguous capital income */

	gen uki=rent_inc+corp_pro+net_int+gov_ent

	/* unambiguous income */

  	gen uci=uki+dep

  	gen ui=uci+uli

	  	gen alpha_uci=uci/ui

	/* ambiguous income */

  	gen ai=prop_inc+sdis+taxes-subsid+bus_t
  

	/* ambiguous capital income */
	/* we assume the proportion of ambiguous capital
	   income to ambiguous incme is the same as the 
	   proportion of unambiguous capital income in unambiguous income */

  	gen aci=alpha_uci*ai


/*------------------------*/
/* generate capital share */
/*------------------------*/

	generate thetap=(uci+aci)/gnp

	/* Alternatively we may proceed as Cooley&Prescott 95 */
	/* generate thetap=(rent_inc+corp_pro+net_int+dep)/(gnp-(sdisp+prop_inc))*/

	generate ykp=thetap*gnp
	replace  kp=kp+inventories
	generate i=(ykp-dep)/kp

	generate deltad=dep_kd/kd
	generate deltag=dep_kg/kg

	generate yd=(i+deltad)*kd
	generate yg=(i+deltag)*kg


/* Without Durables nor Gov */
	generate theta=(ykp)/(gnp)
	egen av_theta=mean(theta)

/* With Durables */
	generate thetad=(ykp+yd)/(gnp+yd)
	egen av_thetad=mean(thetad)

/* With Government */
	generate thetag=(ykp+yg)/(gnp+yg)
	egen av_thetag=mean(thetag)

/* With Durables and Government */
	generate thetadg=(ykp+yd+yg)/(gnp+yd+yg)
	egen av_thetadg=mean(thetadg)

/*-----------------------------*/
/* generate labor share and z2 */
/*-----------------------------*/

/* LS 	=  1 - capital share of income 
	=  (1 - av_thetad) + z2 */

	gen KS = theta
	gen LS = 1-KS
	
	gen KSd = thetad
	gen LSd = 1-KSd

	gen KSg = thetag
	gen LSg = 1-KSg

	gen KSdg = thetadg
	gen LSdg = 1-KSdg

/*compute capital output ratios   */

gen KY   =  kp/gnp
gen KYd  = (kp+kd)/(gnp+yd)
gen KYdg = (kp+kd+kg)/(gnp+yd+yg)

sum KY KYd KYdg


gen rkp=(1-LS)*gnp/kp
gen rkd=(1-LSd)*(gnp+yd)/(kp+kd)
gen rkg=(1-LSdg)*(gnp+yd+yg)/(kp+kd+kg)




/* That is to say that z2 measures the deviation of LS from its mean */

gen z2   = - (1-av_theta)   + LS
gen z2d  = - (1-av_thetad)  + LSd
gen z2g  = - (1-av_thetag)  + LSg
gen z2dg = - (1-av_thetadg) + LSdg

gen gz2   = z2   - L.z2
gen gz2d  = z2d  - L.z2d
gen gz2g  = z2g  - L.z2g
gen gz2dg = z2dg - L.z2dg

gen lnLS   = log(LS)
gen lnLSd  = log(LSd)
gen lnLSg  = log(LSg)
gen lnLSdg = log(LSdg)

merge using "C:\VAR5\Redshocks\ce.dta"
rename col8 govin
gen lnce	=ln(ce)
gen lnws	=ln(ws)
gen lngov	=ln(gov)
gen lnpriv	=ln(priv)
gen lnsuppl	=ln(suppl)
gen lnprivin	=ln(privin)
gen lngovin	=ln(govin)

gen LSce	= ce/gnp
gen LSws	= ws/gnp
gen LSgov	= gov/gnp
gen LSpriv	= priv/gnp
gen LSsuppl	= suppl/gnp
gen LSprivin= privin/gnp
gen LSgovin	= govin/gnp

gen lnLSce		= ln(LSce)
gen lnLSws		= ln(LSws)
gen lnLSgov		= ln(LSgov)
gen lnLSpriv	= ln(LSpriv)
gen lnLSsuppl	= ln(LSsuppl)
gen lnLSprivin	= ln(LSprivin)
gen lnLSgovin	= ln(LSgovin)

hprescott8 lnce,   stub(h) smooth(1600)
hprescott8 lnws,   stub(h) smooth(1600)
hprescott8 lngov,   stub(h) smooth(1600)
hprescott8 lnpriv,   stub(h) smooth(1600)
hprescott8 lnsuppl,   stub(h) smooth(1600)
hprescott8 lnprivin,   stub(h) smooth(1600)
hprescott8 lngovin,   stub(h) smooth(1600)

hprescott8 lnLSce,   stub(h) smooth(1600)
hprescott8 lnLSws,   stub(h) smooth(1600)
hprescott8 lnLSgov,   stub(h) smooth(1600)
hprescott8 lnLSpriv,   stub(h) smooth(1600)
hprescott8 lnLSsuppl,   stub(h) smooth(1600)
hprescott8 lnLSprivin,   stub(h) smooth(1600)
hprescott8 lnLSgovin,   stub(h) smooth(1600)

gen elnce		=h_lnce_1
gen elnws		=h_lnws_1
gen elngov		=h_lngov_1
gen elnpriv		=h_lnpriv_1
gen elnsuppl	=h_lnsuppl_1
gen elnprivin	=h_lnprivin_1
gen elngovin	=h_lngovin_1

gen elnLSce		=h_lnLSce_1
gen elnLSws		=h_lnLSws_1
gen elnLSgov	=h_lnLSgov_1
gen elnLSpriv	=h_lnLSpriv_1
gen elnLSsuppl	=h_lnLSsuppl_1
gen elnLSprivin	=h_lnLSprivin_1
gen elnLSgovin	=h_lnLSgovin_1




/* STATA 9 */


hprescott8 LS,   stub(h) smooth(1600)
hprescott8 LSd,  stub(h) smooth(1600)
hprescott8 LSg,  stub(h) smooth(1600)
hprescott8 LSdg, stub(h) smooth(1600)

gen eLS   = h_LS_1
gen eLSd  = h_LSd_1
gen eLSg  = h_LSg_1
gen eLSdg = h_LSdg_1

hprescott8 z2,   stub(h) smooth(1600)
hprescott8 z2d,  stub(h) smooth(1600)
hprescott8 z2g,  stub(h) smooth(1600)
hprescott8 z2dg, stub(h) smooth(1600)

gen ez2   = h_z2_1
gen ez2d  = h_z2d_1
gen ez2g  = h_z2g_1
gen ez2dg = h_z2dg_1 

hprescott8 lnLS,   stub(h) smooth(1600)
hprescott8 lnLSd,  stub(h) smooth(1600)
hprescott8 lnLSg,  stub(h) smooth(1600)
hprescott8 lnLSdg, stub(h) smooth(1600)

gen elnLS   = h_lnLS_1
gen elnLSd  = h_lnLSd_1
gen elnLSg  = h_lnLSg_1
gen elnLSdg = h_lnLSdg_1



gen r=KS*gnp/kp
gen     gnp_c = gnp
replace gnp	 = gnp*100/gnp_defl
gen lngnp=log(gnp)
hprescott8 lngnp,   stub(h) smooth(1600)
gen elngnp = h_lngnp_1

replace uli	 = uli*100/gnp_defl
gen lnuli=log(uli)
hprescott8 lnuli,   stub(h) smooth(1600)
gen elnuli = h_lnuli_1

* generate aggregate hours
 
 gen  h = hours*n

gen hy=h/gnp
gen lnhy=log(hy)
hprescott8 lnhy,   stub(h) smooth(1600)
gen elnhy = h_lnhy_1

gen lnh=log(h)
hprescott8 lnh,   stub(h) smooth(1600)
gen elnh=h_lnh_1

gen w=LS*gnp/h
gen lnw=log(w)
hprescott8 lnw,   stub(h) smooth(1600)
gen elnw=h_lnw_1



gen lnr=log(r)
hprescott8 lnr,   stub(h) smooth(1600)
gen elnr=h_lnr_1

regress lnw t
predict xbw
gen ulnw=lnw-xbw

regress lnr t
predict xbr
gen ulnr=lnr-xbr

regress lngnp t
predict xbgnp
gen ulngnp=lngnp-xbgnp

regress lnh t
predict xbh
gen ulnh=lnh-xbh

egen mLS=mean(LS)
 gen dLS=LS-mLS

xcorr elngnp eLS, lags(5)
xcorr elngnp eLS if year <1984, lags(5)
xcorr elngnp eLS if year >1983, lags(5)
xcorr elngnp eLS if year >1990, lags(5)

gen LSuli=uli/gnp
hprescott8 LSuli,   stub(h) smooth(1600)
gen eLSuli=h_LSuli_1
gen lnLSuli=log(LSuli)
hprescott8 lnLSuli,   stub(h) smooth(1600)
gen elnLSuli=h_lnLSuli_1

egen av_thetauli=mean(LSuli)
gen z2uli=LSuli-av_thetauli


gen	rce	 = ce*100/gnp_defl
gen   lnrce=log(rce)
hprescott8 lnrce,   stub(h) smooth(1600)
gen elnrce = h_lnrce_1

gen	rws	 = ws*100/gnp_defl
gen   lnrws=log(rws)
hprescott8 lnrws,   stub(h) smooth(1600)
gen elnrws = h_lnrws_1

gen	rgov	 = gov*100/gnp_defl
gen   lnrgov=log(rgov)
hprescott8 lnrgov,   stub(h) smooth(1600)
gen elnrgov = h_lnrgov_1

gen	rpriv	 = priv*100/gnp_defl
gen   lnrpriv=log(rpriv)
hprescott8 lnrpriv,   stub(h) smooth(1600)
gen elnrpriv = h_lnrpriv_1

gen	rsuppl = suppl*100/gnp_defl
gen   lnrsuppl=log(rsuppl)
hprescott8 lnrsuppl,   stub(h) smooth(1600)
gen elnrsuppl = h_lnrsuppl_1

gen	rgovin = govin*100/gnp_defl
gen   lnrgovin=log(rgovin)
hprescott8 lnrgovin,   stub(h) smooth(1600)
gen elnrgovin = h_lnrgovin_1

gen	rprivin = privin*100/gnp_defl
gen   lnrprivin=log(rprivin)
hprescott8 lnrprivin,   stub(h) smooth(1600)
gen elnrprivin = h_lnrprivin_1



sum          elnce elnws elngov elnpriv elnsuppl elngovin elnprivin 
corr  elngnp elnce elnws elngov elnpriv elnsuppl elngovin elnprivin
xcorr elngnp elnce, lags(5) table
xcorr elngnp elnws, lags(5) table
xcorr elngnp elngov, lags(5) table
xcorr elngnp elnpriv, lags(5) table
xcorr elngnp elnsuppl, lags(5) table
xcorr elngnp elngovin, lags(5) table
xcorr elngnp elnprivin, lags(5) table

sum          elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin
corr  elngnp elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin
xcorr elngnp elnLSce, lags(5) table
xcorr elngnp elnLSws, lags(5) table
xcorr elngnp elnLSgov, lags(5) table
xcorr elngnp elnLSpriv, lags(5) table
xcorr elngnp elnLSsuppl, lags(5) table
xcorr elngnp elnLSgovin, lags(5) table
xcorr elngnp elnLSprivin, lags(5) table

sum          elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin
corr  elngnp elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin
xcorr elngnp elnrce, lags(5) table
xcorr elngnp elnrws, lags(5) table
xcorr elngnp elnrgov, lags(5) table
xcorr elngnp elnrpriv, lags(5) table
xcorr elngnp elnrsuppl, lags(5) table
xcorr elngnp elnrgovin, lags(5) table
xcorr elngnp elnrprivin, lags(5) table

sum          elnce elnws elngov elnpriv elnsuppl elngovin elnprivin if year<=1983
corr  elngnp elnce elnws elngov elnpriv elnsuppl elngovin elnprivin if year<=1983
xcorr elngnp elnce if year<=1983, lags(5) table
xcorr elngnp elnws if year<=1983, lags(5) table
xcorr elngnp elngov if year<=1983, lags(5) table
xcorr elngnp elnpriv if year<=1983, lags(5) table
xcorr elngnp elnsuppl if year<=1983, lags(5) table
xcorr elngnp elngovin if year<=1983, lags(5) table
xcorr elngnp elnprivin if year<=1983, lags(5) table

sum          elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin if year<=1983
corr  elngnp elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin if year<=1983

xcorr elngnp elnLSce if year<=1983, lags(5) table
xcorr elngnp elnLSws if year<=1983, lags(5) table
xcorr elngnp elnLSgov if year<=1983, lags(5) table
xcorr elngnp elnLSpriv if year<=1983, lags(5) table
xcorr elngnp elnLSsuppl if year<=1983, lags(5) table
xcorr elngnp elnLSgovin if year<=1983, lags(5) table
xcorr elngnp elnLSprivin if year<=1983, lags(5) table

sum          elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin if year<=1983
corr  elngnp elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin if year<=1983
xcorr elngnp elnrce if year<=1983, lags(5) table
xcorr elngnp elnrws if year<=1983, lags(5) table
xcorr elngnp elnrgov if year<=1983, lags(5) table
xcorr elngnp elnrpriv if year<=1983, lags(5) table
xcorr elngnp elnrsuppl if year<=1983, lags(5) table
xcorr elngnp elnrgovin if year<=1983, lags(5) table
xcorr elngnp elnrprivin if year<=1983, lags(5) table

sum          elnce elnws elngov elnpriv elnsuppl elngovin elnprivin if year>1983 
corr  elngnp elnce elnws elngov elnpriv elnsuppl elngovin elnprivin if year>1983
xcorr elngnp elnce if year>1983, lags(5) table
xcorr elngnp elnws if year>1983, lags(5) table
xcorr elngnp elngov if year>1983, lags(5) table
xcorr elngnp elnpriv if year>1983, lags(5) table
xcorr elngnp elnsuppl if year>1983, lags(5) table
xcorr elngnp elngovin if year>1983, lags(5) table
xcorr elngnp elnprivin if year>1983, lags(5) table

sum          elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin if year>1983
corr  elngnp elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin if year>1983
xcorr elngnp elnLSce if year>1983, lags(5) table
xcorr elngnp elnLSws if year>1983, lags(5) table
xcorr elngnp elnLSgov if year>1983, lags(5) table
xcorr elngnp elnLSpriv if year>1983, lags(5) table
xcorr elngnp elnLSsuppl if year>1983, lags(5) table
xcorr elngnp elnLSgovin if year>1983, lags(5) table
xcorr elngnp elnLSprivin if year>1983, lags(5) table

sum          elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin if year>1983
corr  elngnp elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin if year>1983
xcorr elngnp elnrce if year>1983, lags(5) table
xcorr elngnp elnrws if year>1983, lags(5) table
xcorr elngnp elnrgov if year>1983, lags(5) table
xcorr elngnp elnrpriv if year>1983, lags(5) table
xcorr elngnp elnrsuppl if year>1983, lags(5) table
xcorr elngnp elnrgovin if year>1983, lags(5) table
xcorr elngnp elnrprivin if year>1983, lags(5) table

sum          elnce elnws elngov elnpriv elnsuppl elngovin elnprivin if year>1990 
corr  elngnp elnce elnws elngov elnpriv elnsuppl elngovin elnprivin if year>1990
xcorr elngnp elnce if year>1990, lags(5) table
xcorr elngnp elnws if year>1990, lags(5) table
xcorr elngnp elngov if year>1990, lags(5) table
xcorr elngnp elnpriv if year>1990, lags(5) table
xcorr elngnp elnsuppl if year>1990, lags(5) table
xcorr elngnp elngovin if year>1990, lags(5) table
xcorr elngnp elnprivin if year>1990, lags(5) table

sum          elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin if year>1990
corr  elngnp elnLSce elnLSws elnLSgov elnLSpriv elnLSsuppl elnLSgovin elnLSprivin if year>1990
xcorr elngnp elnLSce if year>1990, lags(5) table
xcorr elngnp elnLSws if year>1990, lags(5) table
xcorr elngnp elnLSgov if year>1990, lags(5) table
xcorr elngnp elnLSpriv if year>1990, lags(5) table
xcorr elngnp elnLSsuppl if year>1990, lags(5) table
xcorr elngnp elnLSgovin if year>1990, lags(5) table
xcorr elngnp elnLSprivin if year>1990, lags(5) table

sum          elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin if year>1990
corr  elngnp elnrce elnrws elnrgov elnrpriv elnrsuppl elnrgovin elnrprivin if year>1990
xcorr elngnp elnrce if year>1990, lags(5) table
xcorr elngnp elnrws if year>1990, lags(5) table
xcorr elngnp elnrgov if year>1990, lags(5) table
xcorr elngnp elnrpriv if year>1990, lags(5) table
xcorr elngnp elnrsuppl if year>1990, lags(5) table
xcorr elngnp elnrgovin if year>1990, lags(5) table
xcorr elngnp elnrprivin if year>1990, lags(5) table


/*
stop

/* corr_hy_w */

rolling , window(40) clear : corr elnhy elnw
gen t=_n
tsset t
gen  corr_hy_w=rho
keep corr_hy_w
save "C:\VAR5\corr40_hy_w"

/* corr_hy_h */

rolling , window(40) clear : corr elnhy elnh
gen t=_n
tsset t
gen  corr_hy_h=rho
keep corr_hy_h
save "C:\VAR5\corr40_hy_h"

/* corr_hy_gnp */

rolling , window(40) clear : corr elnhy elngnp
gen t=_n
tsset t
gen  corr_hy_gnp=rho
keep corr_hy_gnp
save "C:\VAR5\corr40_hy_gnp"

/* corr_hy_LS */

rolling , window(40) clear : corr elnhy elnLS
gen t=_n
tsset t
gen  corr_hy_LS=rho
keep corr_hy_LS
save "C:\VAR5\corr40_hy_LS"







/* corr_h_w */

rolling , window(40) clear : corr elnh elnw
gen t=_n
tsset t
gen  corr_h_w=rho
keep corr_h_w
save "C:\VAR5\corr40_h_w"

/* corr_LS_w */

rolling , window(40) clear : corr elnLS elnw
gen t=_n
tsset t
gen  corr_LS_w=rho
keep corr_LS_w
save "C:\VAR5\corr40_LS_w"

/* corr_LS_h */

rolling , window(40) clear : corr elnLS elnh
gen t=_n
tsset t
gen  corr_LS_h=rho
keep corr_LS_h
save "C:\VAR5\corr40_LS_h"

/* corr_gnp_h */

rolling , window(40) clear : corr elngnp elnh
gen t=_n
tsset t
gen  corr_gnp_h=rho
keep corr_gnp_h
save "C:\VAR5\corr40_gnp_h"

/* corr_gnp_w */

rolling , window(40) clear : corr elngnp elnw
gen t=_n
tsset t
gen  corr_gnp_w=rho
keep corr_gnp_w
save "C:\VAR5\corr40_gnp_w"

/* corr_gnp_LS */

rolling , window(40) clear : corr elngnp elnLS
gen t=_n
tsset t
gen  corr_gnp_LS=rho
keep corr_gnp_LS
save "C:\VAR5\corr40_gnp_LS"

/* use */

use          "C:\VAR5\corr40_h_w"
merge using  "C:\VAR5\corr40_LS_w"
 drop _merge
merge using  "C:\VAR5\corr40_LS_h"
 drop _merge
merge using  "C:\VAR5\corr40_gnp_h"
 drop _merge
merge using  "C:\VAR5\corr40_gnp_w"
 drop _merge
merge using  "C:\VAR5\corr40_gnp_LS"
 drop _merge
merge using  "C:\VAR5\corr40_hy_w"
 drop _merge
merge using  "C:\VAR5\corr40_hy_h"
 drop _merge
merge using  "C:\VAR5\corr40_hy_gnp"
 drop _merge
merge using  "C:\VAR5\corr40_hy_LS"
 drop _merge

gen t=_n
tsset t

tsgraph corr_gnp_LS corr_gnp_w corr_gnp_h corr_LS_h corr_LS_w corr_h_w


stop

rolling sd=r(sd), window(30) clear : sum elngnp, detail
rolling sd=r(sd), window(30) clear : sum elnLS, detail


stop



/* STATA 8 */

/*

hpfilter LS,     lambda(1600)
hpfilter LSd,    lambda(1600)
hpfilter LSg,    lambda(1600)
hpfilter LSdg,   lambda(1600)

gen eLS   = LS   - H_LS
gen eLSd  = LSd  - H_LSd
gen eLSg  = LSg  - H_LSg
gen eLSdg = LSdg - H_LSdg

hpfilter z2,     lambda(1600)
hpfilter z2d,    lambda(1600)
hpfilter z2g,    lambda(1600)
hpfilter z2dg,   lambda(1600)

gen ez2   = z2   - H_z2
gen ez2d  = z2d  - H_z2d
gen ez2g  = z2g  - H_z2g
gen ez2dg = z2dg - H_z2dg 

*/


*/
